@@ -34,7 +34,7 @@ struct FVar: public Config::FloatVar, public GuiVar {
 };
 
 /// Passepartout-specific config file reader.
-class PFile: public Config::File, public SigC::Object {
+class PFile: public Config::File, public sigc::trackable {
 public:
 
   /// The global instance.
@@ -43,7 +43,7 @@ public:
   FVar ReshapeBoxSize, DefaultResolution, ZoomLevel, StartPage;
   BVar Landscape, FakeTransparency, SingleSided;
   SVar PaperName, PrintCommand, StylesheetPath,
-    DefaultStylesheet, DocTemplatePath, PSInterpreter, PSViewer,
+    DefaultStylesheet, DocTemplatePath, PSInterpreter,
     LengthUnit;
 
   PFile();
