@@ -20,8 +20,8 @@ RasterFrame::RasterFrame(const ElementWrap& xml, Group *parent)
   if(association.empty())
     throw Error::Read("\"file\" attribute missing or empty in RasterFrame");
   
-  filewatcher.modified_signal.connect(slot(*this, 
-					   &RasterFrame::on_file_modified));
+  filewatcher.modified_signal.connect
+    (sigc::mem_fun(*this, &RasterFrame::on_file_modified));
   on_file_modified();
   
   // Handle widht and height for backwards compatibility
@@ -40,8 +40,8 @@ RasterFrame::RasterFrame(Group* parent, const std::string& filename,
   : BasicFrame(parent, "Raster " + basename(filename)),
    association(filename), filewatcher(association)
 {
-  filewatcher.modified_signal.connect(slot(*this, 
-					   &RasterFrame::on_file_modified));
+  filewatcher.modified_signal.connect
+    (sigc::mem_fun(*this, &RasterFrame::on_file_modified));
  
   try {
     filepixbuf = Gdk::Pixbuf::create_from_file(association);
@@ -70,7 +70,7 @@ void RasterFrame::on_file_modified() {
     warning << e.what() << std::endl;
   }
 
-  object_changed_signal(this);
+  object_changed_signal();
 }
 
 std::string RasterFrame::getTypeName() const { return "raster"; }
@@ -202,10 +202,7 @@ void RasterFrame::print(std::ostream &out, bool grayscale) const {
 	  guchar g = guchar(0.3 * pixel[0]     // r
 			    + 0.59 * pixel[1]  // g
 			    + 0.11 * pixel[2]  // b
-			    + 0.5); /// \todo "+ 0.5" ??? This was added
-				    /// in revision 1.60, before the
-				    /// move to document/, but I dont
-				    /// know why.
+			    + 0.5);
 	  buffer[i++] = g;
 	} else {
 	  // memcpy?
@@ -280,7 +277,7 @@ void RasterFrame::set_association(const std::string &s) {
   filewatcher.set_file(association);
   
   on_file_modified();
-  props_changed_signal(this);
+  props_changed_signal();
 }
 
 Boundary RasterFrame::get_box() const {
