@@ -11,6 +11,7 @@
 #include "util/warning.h"
 #include "util/stringutil.h" // tostr
 #include "fonts/fontmanager.hh" // getFontPaths
+#include "widget/usererror.h"
 #include <sstream>
 
 /// \todo Remote the following line!
@@ -24,10 +25,12 @@ namespace {
     if(devicename.empty()) {
       verbose << "Deciding which ghostscript device to use ..." << std::endl;
 
+      /// \todo Get a "required" attribute from the configuration!
       const std::string &psinterpreter = config.PSInterpreter.values.front();
       if(psinterpreter.empty())
-	throw GenPicError(BasicFrame::GENERATION,
-			  "No PostScript interpreter specified");
+	throw UserError("No postscript interpreter specified.",
+			"You probably have a configuration file without the"
+			" PSInterpreter property set.");
       
       if(ProcessManager::instance()
 	 .system(psinterpreter + " -q -dBATCH -sDEVICE=pngalpha") == 0)
@@ -51,12 +54,12 @@ PostscriptViewent::PostscriptViewent(View& view, const FrameRef psframe,
     scale_factor = 1;
   
   ProcessManager::instance().process_stopped.connect
-    (slot(*this, &PostscriptViewent::process_stopped));
+    (sigc::mem_fun(*this, &PostscriptViewent::process_stopped));
   /// \todo  Only regenerate when necessary, i.e. not when just moving ...
   frame->object_changed_signal.connect
-    (SigC::hide<Pagent*>(slot(*this, &PostscriptViewent::regenerate)));
+    (sigc::mem_fun(*this, &PostscriptViewent::regenerate));
   view.connect_zoom_change
-    (SigC::hide<float>(slot(*this, &PostscriptViewent::regenerate)));
+    (sigc::hide(sigc::mem_fun(*this, &PostscriptViewent::regenerate)));
 
   canvas_pixbuf.reset(new Gnome::Canvas::Pixbuf(*content_group));
   canvas_pixbuf->property_anchor() = Gtk::ANCHOR_SOUTH_WEST;
@@ -65,7 +68,8 @@ PostscriptViewent::PostscriptViewent(View& view, const FrameRef psframe,
   canvas_pixbuf->property_height_set() = true;
   canvas_pixbuf->property_width_in_pixels() = false;
   canvas_pixbuf->property_height_in_pixels() = false;
-  on_geometry_changed(psframe);
+  on_properties_changed();
+  on_geometry_changed();
   regenerate();
 }
 
@@ -92,8 +96,8 @@ void PostscriptViewent::set_state(State state) {
   }
 }
 
-void PostscriptViewent::on_geometry_changed(Pagent *pagent) {
-  Viewent::on_geometry_changed(pagent);
+void PostscriptViewent::on_geometry_changed() {
+  Viewent::on_geometry_changed();
 
   Vector size = frame->get_inherent_size();
 
@@ -110,7 +114,7 @@ void PostscriptViewent::regenerate() {
     pid = P_STARTUP;
     
     Glib::signal_timeout().connect
-      (SigC::slot(*this, &PostscriptViewent::regenerate_bg),
+      (sigc::mem_fun(*this, &PostscriptViewent::regenerate_bg),
        200, Glib::PRIORITY_DEFAULT_IDLE);
   }
 }
@@ -120,11 +124,13 @@ bool PostscriptViewent::regenerate_bg() {
   try {
     set_state(WAIT);
     redraw_requested = false;
-    
-    std::string &psinterpreter = config.PSInterpreter.values.front();
+     
+    /// \todo Get a "required" attribute from the configuration!
+    const std::string &psinterpreter = config.PSInterpreter.values.front();
     if(psinterpreter.empty())
-      throw GenPicError(BasicFrame::GENERATION,
-                        "No PostScript interpreter specified");
+      throw UserError("No postscript interpreter specified.",
+		      "You probably have a configuration file without the"
+		      " PSInterpreter property set.");
     
     const Matrix &m = frame->get_matrix();
     const Vector framesize = frame->get_inherent_size();
@@ -159,11 +165,7 @@ bool PostscriptViewent::regenerate_bg() {
         << scale_factor * pv.get_y()
 	<< " -sOutputFile=" << tmp_file << " -";
     Process proc = ProcessManager::instance().run(tmp.str());
-    
-    if((pid = proc->get_pid()) == -1)
-      throw GenPicError(BasicFrame::GENERATION,
-                        "Failed to run " + psinterpreter);
-    
+    pid = proc->get_pid();
     verbose << pid << ": " << tmp.str() << std::endl;
     
     frame->generate_picture(proc->get_cin());
@@ -174,17 +176,20 @@ bool PostscriptViewent::regenerate_bg() {
       redraw_requested = true;	// simply try again
     else {
       set_state(e.type == BasicFrame::ASSOCIATION ? MISSING : BROKEN);
-      warning << frame->get_name() << ": " << e.what() << std::endl;
+      warning << "PostScriptviewent for " << frame->get_name()
+	      << ": GenPicError: " << e.what() << std::endl;
     }
     pid = P_IDLE;
   } catch(const std::exception& e) {
     stop_process();
-    warning << frame->get_name() << ": " << e.what() << std::endl;
+    warning << "PostScriptviewent for " << frame->get_name() << ": "
+	    << e.what() << std::endl;
     set_state(BROKEN);
     pid = P_IDLE;
   } catch(...) {
     stop_process();
-    warning << frame->get_name() << ": Unknown error" << std::endl;
+    warning << "PostScriptviewent for" << frame->get_name()
+	    << ": Unknown error" << std::endl;
     set_state(BROKEN);
     pid = P_IDLE;
   }
@@ -224,7 +229,7 @@ void PostscriptViewent::process_stopped(pid_t _pid, bool exited_normally,
                                     Gdk::INTERP_BILINEAR);
 
     canvas_pixbuf->property_pixbuf() = pixbuf;
-    on_geometry_changed(frame);
+    on_geometry_changed();
     set_state(NORMAL);
   
   } catch(const std::exception& e) {
