@@ -16,6 +16,8 @@
 
 #include "document/textstream.h"
 #include "document/document.h"
+#include "document/page.h"
+#include "document/textframe.h"
 
 #include "streamdialog.h"
 #include "config.h"
@@ -61,10 +63,10 @@ StreamDialog &StreamDialog::instance() {
 }
 
 namespace {
-  SigC::Slot1<bool, GdkEventFocus*> 
-  adapt_focus_out(SigC::Slot1<void, int> slot, int response_id) {
-    return SigC::hide<GdkEventFocus*>(SigC::bind_return
-                                      (SigC::bind(slot, response_id), true));
+  sigc::slot<bool, GdkEventFocus*> 
+  adapt_focus_out(sigc::slot<void, int> slot, int response_id) {
+    return sigc::hide(sigc::bind_return(sigc::bind(slot, response_id), 
+                                        true));
   }
 }
 
@@ -90,7 +92,7 @@ StreamDialog::StreamDialog()
     
     Glib::RefPtr<Gtk::TreeSelection> selection = stream_list.get_selection();
     selection->signal_changed().connect
-      (slot(*this, &StreamDialog::on_selection_changed));
+      (sigc::mem_fun(*this, &StreamDialog::on_selection_changed));
     
     Gtk::ScrolledWindow *scroll = manage(new Gtk::ScrolledWindow());
     scroll->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
@@ -142,7 +144,7 @@ StreamDialog::StreamDialog()
       line = manage(new Gtk::HBox(false, double_space));
       label = manage(new Gtk::Label("_Stylesheet:", 1.0, 0.5, true));
       sizegroup->add_widget(*label);
-      label->set_mnemonic_widget(*xfrm_entry.entry.get_entry());
+      label->set_mnemonic_widget(xfrm_entry.entry.get_entry());
       line->pack_start(*label, Gtk::PACK_SHRINK);
       line->pack_start(xfrm_entry, Gtk::PACK_EXPAND_WIDGET);
       box->pack_start(*line, Gtk::PACK_SHRINK);
@@ -159,7 +161,7 @@ StreamDialog::StreamDialog()
       param_list.append_column_editable("Value", param_columns.value);
       param_list.property_height_request() = 90;
       param_model->signal_row_changed().connect
-	(slot(*this, &StreamDialog::on_param_row_changed));
+	(sigc::mem_fun(*this, &StreamDialog::on_param_row_changed));
       Gtk::ScrolledWindow *scroll = manage(new Gtk::ScrolledWindow());
       scroll->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
       scroll->set_shadow_type(Gtk::SHADOW_IN);
@@ -174,24 +176,24 @@ StreamDialog::StreamDialog()
   show_all_children();
 
   Document::streams_changed_signal.connect
-    (slot(*this, &StreamDialog::_update));
+    (sigc::mem_fun(*this, &StreamDialog::_update));
    
   name_entry.signal_activate().connect
-    (bind(slot(*this, &StreamDialog::on_response), Response::SETNAME));
+    (bind(sigc::mem_fun(*this, &StreamDialog::on_response), Response::SETNAME));
   name_entry.signal_focus_out_event().connect
-    (adapt_focus_out(slot(*this, &StreamDialog::on_response),
+    (adapt_focus_out(sigc::mem_fun(*this, &StreamDialog::on_response),
                      Response::SETNAME));
   
-  file_entry.entry.get_entry()->signal_activate().connect
-    (bind(slot(*this, &StreamDialog::on_response), Response::SETFILE));
-  file_entry.entry.get_entry()->signal_focus_out_event().connect
-    (adapt_focus_out(slot(*this, &StreamDialog::on_response),
+  file_entry.entry.get_entry().signal_activate().connect
+    (bind(sigc::mem_fun(*this, &StreamDialog::on_response), Response::SETFILE));
+  file_entry.entry.get_entry().signal_focus_out_event().connect
+    (adapt_focus_out(sigc::mem_fun(*this, &StreamDialog::on_response),
                      Response::SETFILE));
   
-  xfrm_entry.entry.get_entry()->signal_activate().connect
-    (bind(slot(*this, &StreamDialog::on_response), Response::SETXFRM));
-  xfrm_entry.entry.get_entry()->signal_focus_out_event().connect
-    (adapt_focus_out(slot(*this, &StreamDialog::on_response),
+  xfrm_entry.entry.get_entry().signal_activate().connect
+    (bind(sigc::mem_fun(*this, &StreamDialog::on_response), Response::SETXFRM));
+  xfrm_entry.entry.get_entry().signal_focus_out_event().connect
+    (adapt_focus_out(sigc::mem_fun(*this, &StreamDialog::on_response),
                      Response::SETXFRM));
 }
 
@@ -224,10 +226,10 @@ Gtk::Button* StreamDialog::fix_button(Gtk::Button* button, int action_id) {
   Gtk::Button *b = manage(button);
   // Note: It seems that activate means "in any way except a simple click".
   // So we have to add callbacks for both activate and clicked.
-  b->signal_clicked().connect(bind(slot(*this, &StreamDialog::on_response),
-                                   action_id));
-  b->signal_activate().connect(bind(slot(*this, &StreamDialog::on_response),
-				    action_id));
+  b->signal_clicked().connect
+    (bind(sigc::mem_fun(*this, &StreamDialog::on_response), action_id));
+  b->signal_activate().connect
+    (bind(sigc::mem_fun(*this, &StreamDialog::on_response), action_id));
   return b;
 }
 
@@ -276,14 +278,14 @@ void StreamDialog::on_response(int response_id) {
     
   case Response::SETFILE:
     if(current_stream)
-      current_stream->set_association(file_entry.entry.get_text(false));
+      current_stream->set_association(file_entry.entry.get_text(true));
     else
       debug << no_stream << std::endl;
     break;
     
   case Response::SETXFRM:
     if(current_stream) {
-      current_stream->set_transform(xfrm_entry.entry.get_text(false));
+      current_stream->set_transform(xfrm_entry.entry.get_text(true));
       update_params(current_stream);
     } else
       debug << no_stream << std::endl;
@@ -325,11 +327,13 @@ void StreamDialog::on_selection_changed() {
     current_selection = name;
 
     TextStream *stream = document->get_text_stream(name);
-    file_entry.entry.set_text(stream->get_association());
+    file_entry.entry.set_text(stream->get_association(),
+                              true /* save history */);
     if(stream->get_transform().empty()) {      //Set default stylesheet
       xfrm_entry.set_default_value(config.DefaultStylesheet.values.front());
     } else {
-      xfrm_entry.entry.set_text(stream->get_transform());
+      xfrm_entry.entry.set_text(stream->get_transform(),
+                                true /* save history */);
     }
 
     update_params(stream);
@@ -360,7 +364,7 @@ void StreamDialog::on_selection_changed() {
 }
 
 void StreamDialog::on_param_row_changed(const Gtk::TreeModel::Path& path,
-					 const Gtk::TreeModel::iterator& iter)
+                                        const Gtk::TreeModel::iterator& iter)
 {
   if(current_stream && iter)
     current_stream->set_parameter(iter->get_value(param_columns.name),
@@ -388,25 +392,17 @@ StreamMenu::StreamMenu() {
 }
 
 std::string StreamMenu::get_stream() const {
-  const Gtk::Label *tmp = dynamic_cast<const Gtk::Label*> (get_child());
-  if(!tmp || tmp->get_text() == no_stream)
-    return ""; 
-  return tmp->get_text();
+  Glib::ustring text = get_active_text();
+  return text == no_stream ? "" : text;
 }
  
 void StreamMenu::update(DocRef document, const std::string &select_name) {
-  Gtk::Menu dummy;
-  set_menu(dummy); //so it will notice the change
-  using namespace Gtk;
-  using namespace Menu_Helpers;
-  MenuList& menu_list = menu.items();
-  menu_list.clear();
+  Glib::RefPtr<Gtk::ListStore>::cast_dynamic(get_model())->clear();
   if(!document) {
-      menu.items().push_back(MenuElem("")); // cosmetic fix
-      menu.set_active(0);
-      set_menu(menu);
-      return;
-    }
+    append_text("-");
+    set_active(0);
+    return;
+  }
   int index = 0;
   Document::StreamVec streams = document->get_text_streams();
   for(Document::StreamVec::iterator i = streams.begin();
@@ -414,16 +410,14 @@ void StreamMenu::update(DocRef document, const std::string &select_name) {
       i++)
     {
       const std::string &name = (*i)->get_name();
-      menu.items().push_back(MenuElem(name));
+      append_text(name);
       if(name == select_name)
-	menu.set_active(index);
+	set_active(index);
       index++;
     }
-  menu.items().push_back(SeparatorElem());
-  menu.items().push_back(MenuElem(no_stream));
+  append_text(no_stream);
   if(select_name.empty())
-    menu.set_active(index + 1);
-  set_menu(menu);
+    set_active(index);
 }
 
 
@@ -476,7 +470,7 @@ TextFrameDialog::TextFrameDialog(Gtk::Window &parent, DocumentView &_view)
   line = manage(new Gtk::HBox(false, double_space));
   label = manage(new Gtk::Label("_Stylesheet:", 1.0, 0.5, true));
   sizegroup->add_widget(*label);
-  label->set_mnemonic_widget(*xfrm_entry.entry.get_entry());
+  label->set_mnemonic_widget(xfrm_entry.entry.get_entry());
   line->pack_start(*label, Gtk::PACK_SHRINK);
   line->pack_start(xfrm_entry, Gtk::PACK_EXPAND_WIDGET);
   new_box->pack_start(*line, Gtk::PACK_SHRINK);
@@ -491,7 +485,7 @@ TextFrameDialog::TextFrameDialog(Gtk::Window &parent, DocumentView &_view)
 
   get_vbox()->pack_start(*main_box);
 
-  Gtk::RadioButton_Helpers::Group group = old_button->get_group();
+  Gtk::RadioButton::Group group = old_button->get_group();
   new_button->set_group(group);
   old_button->set_active();
   fix_button(new_button, RESPONSE_TOGGLE_MODE);
@@ -511,6 +505,13 @@ void TextFrameDialog::show_raise() {
   DialogWrap::show_raise();
 }
 
+namespace {
+  void new_text_frame(TextStream *stream, Page *page) {
+    int w = 200, h = 300;
+    page->addObject(new TextFrame(page, stream, w, h));
+  }
+}
+
 void TextFrameDialog::on_response(int response_id) {
   switch(response_id) {
   case Gtk::RESPONSE_OK:
@@ -529,7 +530,7 @@ void TextFrameDialog::on_response(int response_id) {
 	throw UserError("Could not create text stream", e.what());
       }
     }
-    view.new_text_frame(stream);
+    new_text_frame(stream, view.get_page());
     hide();
     break;
   case Gtk::RESPONSE_CANCEL:
