@@ -27,7 +27,7 @@ public:
   virtual const Gdk::Color& get_color(Color::Id color) const = 0;
 
   /** Register a callback for the signal raised on rescaling the view */
-  virtual SigC::Connection connect_zoom_change(SigC::Slot1<void, float>) = 0;
+  virtual sigc::connection connect_zoom_change(sigc::slot<void, float>) = 0;
 };
 
 #endif
