@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "barrier.h"
 
@@ -17,8 +17,10 @@ void Barrier::wait() {
 
 void Barrier::open() {
   Glib::Mutex::Lock lock(mutex);
-  is_open = true;
-  cond.broadcast();
+  if(!is_open) {
+    is_open = true;
+    cond.broadcast();
+  }
 }
 
 void Barrier::reclose() {
