@@ -20,6 +20,9 @@ bool exists(const std::string& filename);
 /// Check if the specified file can be accessed
 bool access(const std::string& filename, int mode = std::ios::in);
 
+/// Check if the file is executable
+bool executable(const std::string& filename);
+
 /// Get date of last modification.
 time_t modified(const std::string& filename);
 
